跳到正文
原文
Hacker News:AI 热帖· shchoholiev·· 6 天前AI 评分59

工程师手动设计 tests-sharder 测试分片方案,让 CI 运行速度提升 70%

I used my brain instead of AI – now CI runs 70% faster

AI 导读

Serhii Shchoholiev 针对编码智能体生成大量测试后 CI 变慢的问题,手动设计基于测试时长的动态分片算法,并用 Rust 实现 tests-sharder,使 CI 运行速度提升 70%。

来源:Hacker News:AI 热帖 · shchoholiev.com